@@ -14,6 +14,10 @@ class ScriptEngineParseError(ScriptEngineError):
     """An error that has to do with parsing SE scripts"""
 
 
+class ScriptEngineParseFileError(ScriptEngineParseError):
+    """An file error while acessing an SE script"""
+
+
 class ScriptEngineParseJinjaError(ScriptEngineParseError):
     """Throw this exception whenever there is a problem with parsing Jinja2
     expressions"""
@@ -32,6 +36,10 @@ class ScriptEngineTaskError(ScriptEngineError):
     """All ScriptEngine Tasks should throw this"""
 
 
+class ScriptEngineTaskLoaderError(ScriptEngineTaskError):
+    """There is a problem while loading an SE task or taskset"""
+
+
 class ScriptEngineTaskArgumentError(ScriptEngineTaskError):
     """There is a problem with an SE Task argument"""
 
